==> realestate-supervise-common-1.0.0-20211126.015821-49-sources.jar: cn/gtmap/realestate/supervise/entity/BaZrz.java <==
package cn.gtmap.realestate.supervise.entity;

import cn.gtmap.realestate.supervise.core.reflect.*;
import com.sun.istack.internal.Nullable;

import javax.persistence.Entity;
import javax.persistence.Id;
import javax.persistence.Table;
import javax.xml.bind.annotation.*;
import java.io.Serializable;
import java.util.Date;

/**
 * @author <a href="mailto:gaofeng@gtmap.cn">gaofeng</a>
 * @version 1.0，2017/6/15
 * @description 自然幢信息
 */

@XmlAccessorType(XmlAccessType.FIELD)
@XmlRootElement
@XmlType
@Entity
@Table(
        name = "ba_zrz"
)
public class BaZrz implements Serializable {

    @XmlAttribute
    private int bsm;

    @XmlAttribute
    private String ysdm;

    @XmlAttribute
    private String bdcdyh;

    @XmlAttribute
    private String zddm;

    @XmlAttribute
    private String zrzh;

    @XmlAttribute
    @Nullable
    private String xmmc;

    @XmlAttribute
    @Nullable
    private String jzwmc;

    @XmlAttribute
    @Nullable
    private Date jgrq;

    @XmlAttribute
    @Nullable
    private String jzwgd;

    @XmlAttribute
    private String zzdmj;

    @XmlAttribute
    private String zydmj;

    @XmlAttribute
    @Nullable
    private String ycjzmj;

    @XmlAttribute
    @Nullable
    private String scjzmj;

    @XmlAttribute
    private String zcs;

    @XmlAttribute
    private String dscs;

    @XmlAttribute
    private String dxcs;

    @XmlAttribute
    @Nullable
    private String dxsd;

    @XmlAttribute
    private String ghyt;

    @XmlAttribute
    private String fwjg;

    @XmlAttribute
    private int zts;

    @XmlAttribute
    @Nullable
    private String dah;

    @XmlAttribute
    @Nullable
    private String bz;

    @XmlAttribute
    private String zt;

    @XmlAttribute
    @qxdm
    private String qxdm;

    @XmlAttribute
    @id
    @Id
    private String id;

    @XmlAttribute
    private String zrzbh;

    @Nullable
    private Date sjgxsj;

    @ywh
    private String ywh;

    @bwmc
    private String bwmc;

    @XmlAttribute
    private String lddm;

    @XmlAttribute
    private String ldzl;

    @XmlAttribute
    private String ytmc;

    @XmlAttribute
    private String pzyt;

    @XmlAttribute
    private String sjyt;

    public String getLddm() {
        return lddm;
    }

    public void setLddm(String lddm) {
        this.lddm = lddm;
    }

    public String getLdzl() {
        return ldzl;
    }

    public void setLdzl(String ldzl) {
        this.ldzl = ldzl;
    }

    public String getYtmc() {
        return ytmc;
    }

    public void setYtmc(String ytmc) {
        this.ytmc = ytmc;
    }

    public String getPzyt() {
        return pzyt;
    }

    public void setPzyt(String pzyt) {
        this.pzyt = pzyt;
    }

    public String getSjyt() {
        return sjyt;
    }

    public void setSjyt(String sjyt) {
        this.sjyt = sjyt;
    }

    public String getBwmc() {
        return bwmc;
    }

    public void setBwmc(String bwmc) {
        this.bwmc = bwmc;
    }

    public Date getSjgxsj() {
        return sjgxsj;
    }

    public void setSjgxsj(Date sjgxsj) {
        this.sjgxsj = sjgxsj;
    }

    public String getId() {
        return id;
    }

    public void setId(String id) {
        this.id = id;
    }


    public int getBsm() {
        return bsm;
    }

    public void setBsm(int bsm) {
        this.bsm = bsm;
    }

    public String getYsdm() {
        return ysdm;
    }

    public void setYsdm(String ysdm) {
        this.ysdm = ysdm;
    }

    public String getBdcdyh() {
        return bdcdyh;
    }

    public void setBdcdyh(String bdcdyh) {
        this.bdcdyh = bdcdyh;
    }

    public String getZddm() {
        return zddm;
    }

    public void setZddm(String zddm) {
        this.zddm = zddm;
    }

    public String getZrzh() {
        return zrzh;
    }

    public void setZrzh(String zrzh) {
        this.zrzh = zrzh;
    }

    public String getXmmc() {
        return xmmc;
    }

    public void setXmmc(String xmmc) {
        this.xmmc = xmmc;
    }

    public String getJzwmc() {
        return jzwmc;
    }

    public void setJzwmc(String jzwmc) {
        this.jzwmc = jzwmc;
    }

    public Date getJgrq() {
        return jgrq;
    }

    public void setJgrq(Date jgrq) {
        this.jgrq = jgrq;
    }

    public String getJzwgd() {
        return jzwgd;
    }

    public void setJzwgd(String jzwgd) {
        this.jzwgd = jzwgd;
    }

    public String getZzdmj() {
        return zzdmj;
    }

    public void setZzdmj(String zzdmj) {
        this.zzdmj = zzdmj;
    }

    public String getZydmj() {
        return zydmj;
    }

    public void setZydmj(String zydmj) {
        this.zydmj = zydmj;
    }

    public String getYcjzmj() {
        return ycjzmj;
    }

    public void setYcjzmj(String ycjzmj) {
        this.ycjzmj = ycjzmj;
    }

    public String getScjzmj() {
        return scjzmj;
    }

    public void setScjzmj(String scjzmj) {
        this.scjzmj = scjzmj;
    }

    public String getZcs() {
        return zcs;
    }

    public void setZcs(String zcs) {
        this.zcs = zcs;
    }

    public String getDscs() {
        return dscs;
    }

    public void setDscs(String dscs) {
        this.dscs = dscs;
    }

    public String getDxcs() {
        return dxcs;
    }

    public void setDxcs(String dxcs) {
        this.dxcs = dxcs;
    }

    public String getDxsd() {
        return dxsd;
    }

    public void setDxsd(String dxsd) {
        this.dxsd = dxsd;
    }

    public String getGhyt() {
        return ghyt;
    }

    public void setGhyt(String ghyt) {
        this.ghyt = ghyt;
    }

    public String getFwjg() {
        return fwjg;
    }

    public void setFwjg(String fwjg) {
        this.fwjg = fwjg;
    }

    public int getZts() {
        return zts;
    }

    public void setZts(int zts) {
        this.zts = zts;
    }

    public String getDah() {
        return dah;
    }

    public void setDah(String dah) {
        this.dah = dah;
    }

    public String getBz() {
        return bz;
    }

    public void setBz(String bz) {
        this.bz = bz;
    }

    public String getZt() {
        return zt;
    }

    public void setZt(String zt) {
        this.zt = zt;
    }

    public String getQxdm() {
        return qxdm;
    }

    public void setQxdm(String qxdm) {
        this.qxdm = qxdm;
    }


    public String getZrzbh() {
        return zrzbh;
    }

    public void setZrzbh(String zrzbh) {
        this.zrzbh = zrzbh;
    }

    public String getYwh() {
        return ywh;
    }

    public void setYwh(String ywh) {
        this.ywh = ywh;
    }
}

==> realestate-supervise-common-1.1.0-20250924.014108-69-sources.jar: cn/gtmap/realestate/supervise/entity/BaZrz.java <==
package cn.gtmap.realestate.supervise.entity;

import cn.gtmap.realestate.supervise.core.reflect.*;
import com.sun.istack.internal.Nullable;

import javax.persistence.Entity;
import javax.persistence.Id;
import javax.persistence.Table;
import javax.xml.bind.annotation.*;
import java.io.Serializable;
import java.util.Date;

/**
 * @author <a href="mailto:gaofeng@gtmap.cn">gaofeng</a>
 * @version 1.0，2017/6/15
 * @description 自然幢信息
 */

@XmlAccessorType(XmlAccessType.FIELD)
@XmlRootElement
@XmlType
@Entity
@Table(
        name = "ba_zrz"
)
public class BaZrz implements Serializable {

    @XmlAttribute
    private String bsm;

    @XmlAttribute
    private String ysdm;

    @XmlAttribute
    private String bdcdyh;

    @XmlAttribute
    private String zddm;

    @XmlAttribute
    private String zrzh;

    @XmlAttribute
    @Nullable
    private String xmmc;

    @XmlAttribute
    @Nullable
    private String jzwmc;

    @XmlAttribute
    @Nullable
    private Date jgrq;

    @XmlAttribute
    @Nullable
    private String jzwgd;

    @XmlAttribute
    private String zzdmj;

    @XmlAttribute
    private String zydmj;

    @XmlAttribute
    @Nullable
    private String ycjzmj;

    @XmlAttribute
    @Nullable
    private String scjzmj;

    @XmlAttribute
    private String zcs;

    @XmlAttribute
    private String dscs;

    @XmlAttribute
    private String dxcs;

    @XmlAttribute
    @Nullable
    private String dxsd;

    @XmlAttribute
    private String ghyt;

    @XmlAttribute
    private String fwjg;

    @XmlAttribute
    private int zts;

    @XmlAttribute
    @Nullable
    private String dah;

    @XmlAttribute
    @Nullable
    private String bz;

    @XmlAttribute
    private String zt;

    @XmlAttribute
    @qxdm
    private String qxdm;

    @XmlAttribute
    @id
    @Id
    private String id;

    @XmlAttribute
    private String zrzbh;

    @Nullable
    private Date sjgxsj;

    @ywh
    private String ywh;

    @bwmc
    private String bwmc;

    @XmlAttribute
    private String lddm;

    @XmlAttribute
    private String ldzl;

    @XmlAttribute
    private String ytmc;

    @XmlAttribute
    private String pzyt;

    @XmlAttribute
    private String sjyt;

    public String getLddm() {
        return lddm;
    }

    public void setLddm(String lddm) {
        this.lddm = lddm;
    }

    public String getLdzl() {
        return ldzl;
    }

    public void setLdzl(String ldzl) {
        this.ldzl = ldzl;
    }

    public String getYtmc() {
        return ytmc;
    }

    public void setYtmc(String ytmc) {
        this.ytmc = ytmc;
    }

    public String getPzyt() {
        return pzyt;
    }

    public void setPzyt(String pzyt) {
        this.pzyt = pzyt;
    }

    public String getSjyt() {
        return sjyt;
    }

    public void setSjyt(String sjyt) {
        this.sjyt = sjyt;
    }

    public String getBwmc() {
        return bwmc;
    }

    public void setBwmc(String bwmc) {
        this.bwmc = bwmc;
    }

    public Date getSjgxsj() {
        return sjgxsj;
    }

    public void setSjgxsj(Date sjgxsj) {
        this.sjgxsj = sjgxsj;
    }

    public String getId() {
        return id;
    }

    public void setId(String id) {
        this.id = id;
    }

    public String getBsm() {
        return bsm;
    }

    public void setBsm(String bsm) {
        this.bsm = bsm;
    }

    public String getYsdm() {
        return ysdm;
    }

    public void setYsdm(String ysdm) {
        this.ysdm = ysdm;
    }

    public String getBdcdyh() {
        return bdcdyh;
    }

    public void setBdcdyh(String bdcdyh) {
        this.bdcdyh = bdcdyh;
    }

    public String getZddm() {
        return zddm;
    }

    public void setZddm(String zddm) {
        this.zddm = zddm;
    }

    public String getZrzh() {
        return zrzh;
    }

    public void setZrzh(String zrzh) {
        this.zrzh = zrzh;
    }

    public String getXmmc() {
        return xmmc;
    }

    public void setXmmc(String xmmc) {
        this.xmmc = xmmc;
    }

    public String getJzwmc() {
        return jzwmc;
    }

    public void setJzwmc(String jzwmc) {
        this.jzwmc = jzwmc;
    }

    public Date getJgrq() {
        return jgrq;
    }

    public void setJgrq(Date jgrq) {
        this.jgrq = jgrq;
    }

    public String getJzwgd() {
        return jzwgd;
    }

    public void setJzwgd(String jzwgd) {
        this.jzwgd = jzwgd;
    }

    public String getZzdmj() {
        return zzdmj;
    }

    public void setZzdmj(String zzdmj) {
        this.zzdmj = zzdmj;
    }

    public String getZydmj() {
        return zydmj;
    }

    public void setZydmj(String zydmj) {
        this.zydmj = zydmj;
    }

    public String getYcjzmj() {
        return ycjzmj;
    }

    public void setYcjzmj(String ycjzmj) {
        this.ycjzmj = ycjzmj;
    }

    public String getScjzmj() {
        return scjzmj;
    }

    public void setScjzmj(String scjzmj) {
        this.scjzmj = scjzmj;
    }

    public String getZcs() {
        return zcs;
    }

    public void setZcs(String zcs) {
        this.zcs = zcs;
    }

    public String getDscs() {
        return dscs;
    }

    public void setDscs(String dscs) {
        this.dscs = dscs;
    }

    public String getDxcs() {
        return dxcs;
    }

    public void setDxcs(String dxcs) {
        this.dxcs = dxcs;
    }

    public String getDxsd() {
        return dxsd;
    }

    public void setDxsd(String dxsd) {
        this.dxsd = dxsd;
    }

    public String getGhyt() {
        return ghyt;
    }

    public void setGhyt(String ghyt) {
        this.ghyt = ghyt;
    }

    public String getFwjg() {
        return fwjg;
    }

    public void setFwjg(String fwjg) {
        this.fwjg = fwjg;
    }

    public int getZts() {
        return zts;
    }

    public void setZts(int zts) {
        this.zts = zts;
    }

    public String getDah() {
        return dah;
    }

    public void setDah(String dah) {
        this.dah = dah;
    }

    public String getBz() {
        return bz;
    }

    public void setBz(String bz) {
        this.bz = bz;
    }

    public String getZt() {
        return zt;
    }

    public void setZt(String zt) {
        this.zt = zt;
    }

    public String getQxdm() {
        return qxdm;
    }

    public void setQxdm(String qxdm) {
        this.qxdm = qxdm;
    }


    public String getZrzbh() {
        return zrzbh;
    }

    public void setZrzbh(String zrzbh) {
        this.zrzbh = zrzbh;
    }

    public String getYwh() {
        return ywh;
    }

    public void setYwh(String ywh) {
        this.ywh = ywh;
    }
}
